@@ -191,7 +191,7 @@ static fsal_status_t create_export(struct fsal_module *module_in,
 	/* Stat for root */
 	struct stat st;
 	/* Return code */
-	int rc;
+	int rc = 0;
 	/* Return code from RGW calls */
 	int rgw_status;
 	/* True if we have called fsal_export_init */
@@ -329,12 +329,7 @@ static fsal_status_t create_export(struct fsal_module *module_in,
 
 	op_ctx->fsal_export = &export->export;
 
-	/* Stack MDCACHE on top */
-	status = mdcache_export_init(up_ops, &export->export.up_ops);
-	if (FSAL_IS_ERROR(status)) {
-		LogDebug(COMPONENT_FSAL, "MDCACHE creation failed for RGW");
-		goto error;
-	}
+	export->export.up_ops = up_ops;
 
 	return status;
 
